@@ -49,7 +49,7 @@ class EmsCliImport:
         Raises:
             EmsCliException
         """
-        from moss.ems.scripts.ems_cli import EmsCliException
+        from moss.ems.scripts.moss_emscli import EmsCliException
         from moss.ems.utilities.sortutil import ObjectClassSorter
 
         logger.info("Starting import process")
